/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.messaging.inbox;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.JScrollPane;
import nl.cloudfarming.client.messaging.Message;
import org.jdesktop.swingx.ScrollableSizeHint;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;
import org.netbeans.api.settings.ConvertAsProperties;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.explorer.ExplorerManager;
import org.openide.util.Lookup;

/**
 * Top component which displays something.
 */
@ConvertAsProperties(dtd = "-//nl.cloudfarming.client.messaging.inbox//Messages//EN",
autostore = false)
@TopComponent.Description(preferredID = "MessagesTopComponent",
iconBase = "nl/cloudfarming/client/icon/mail-message-new.png",
persistenceType = TopComponent.PERSISTENCE_ALWAYS)
@TopComponent.Registration(mode = "properties", openAtStartup = false)
@ActionID(category = "Window", id = "nl.cloudfarming.client.messaging.inbox.MessagesTopComponent")
@ActionReference(path = "Menu/Window/Application Output" /*, position = 333 */)
@TopComponent.OpenActionRegistration(displayName = "#CTL_MessagesAction",
preferredID = "MessagesTopComponent")
public final class MessagesTopComponent extends TopComponent implements ExplorerManager.Provider, PropertyChangeListener {

    private ExplorerManager explorerManager;
//    private OutlineView view = new OutlineView();
    private final MessagesPanel messagesPanel = new MessagesPanel();
    private boolean initialized = false;
    private final JScrollPane scrollPane;

    public MessagesTopComponent() {
        setName(NbBundle.getMessage(MessagesTopComponent.class, "CTL_MessagesTopComponent"));
        setToolTipText(NbBundle.getMessage(MessagesTopComponent.class, "HINT_MessagesTopComponent"));
        MessageInbox inbox = Lookup.getDefault().lookup(MessageInbox.class);
        explorerManager = inbox.getExplorerManager();
        associateLookup(inbox.getLookup());


        messagesPanel.setScrollableHeightHint(ScrollableSizeHint.NONE);
        messagesPanel.setScrollableWidthHint(ScrollableSizeHint.NONE);
        scrollPane = new JScrollPane(messagesPanel, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
//        setLayout(new BorderLayout());
        add(scrollPane);
//        scrollPane.setViewportView(messagesPanel);
//        scrollPane.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
//        scrollPane.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
//        view.setPropertyColumns("imageIcon","imageIcon","image","image","title","title","messageText","messageText");


    }

    @Override
    public void componentOpened() {
        MessageInbox inbox = Lookup.getDefault().lookup(MessageInbox.class);
        inbox.addMessagePropertyChangeListener(this);
        if (!initialized) {
            for (Message message : inbox.getMessages()) {
                messagesPanel.addMessage(message);
            }
            initialized = true;
        }
    }

    @Override
    public void componentClosed() {
        MessageInbox inbox = Lookup.getDefault().lookup(MessageInbox.class);
        inbox.removeMessagePropertyChangeListener(this);        
    }

    void writeProperties(java.util.Properties p) {
        // better to version settings since initial version as advocated at
        // http://wiki.apidesign.org/wiki/PropertyFiles
        p.setProperty("version", "1.0");
    }

    void readProperties(java.util.Properties p) {
        String version = p.getProperty("version");
    }

    @Override
    public ExplorerManager getExplorerManager() {
        return explorerManager;
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        if(MessageInbox.PROPERTY_ADDED.equals(evt.getPropertyName())){
            messagesPanel.addMessage((Message)evt.getNewValue());
        }
    }
}
